@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -231,28 +231,39 @@ void menu_info_item_update(menu_info_t* mi, uint32_t index, const char* name,
         return;
     }
 
-    menu_infos_t* mis = item->menu_info->menu_infos;
-
     g_debug("[menu_info] updating %s %u %s (target: %d)",
             menu_info_type_name(item->menu_info->type), index, desc, (int)target);
 
-    g_free(item->name);
-    item->name = g_strdup(name);
+    if (name != item->name)
+    {
+        g_free(item->name);
+        item->name = g_strdup(name);
+    }
 
-    g_free(item->desc);
-    item->desc = g_strdup(desc);
+    if (desc != item->desc)
+    {
+        g_free(item->desc);
+        item->desc = g_strdup(desc);
+    }
 
     /* only notify on volume / mute changes */
     int notify = 0;
     if ((vol && !pa_cvolume_equal(item->volume, vol)) || mute != item->mute)
         notify = 1;
 
-    g_free(item->volume);
-    item->volume = g_memdup(vol, sizeof(pa_cvolume));
+    if (vol != item->volume)
+    {
+        g_free(item->volume);
+        item->volume = g_memdup(vol, sizeof(pa_cvolume));
+    }
     item->mute = mute;
     item->target = target;
-    g_free(item->address);
-    item->address = g_strdup(address);
+
+    if (address != item->address)
+    {
+        g_free(item->address);
+        item->address = g_strdup(address);
+    }
 
     menu_type_t submenu_type = menu_info_submenu_type(mi->type);
     menu_info_t* submenu = &mi->menu_infos->menu_info[submenu_type];
@@ -261,7 +272,8 @@ void menu_info_item_update(menu_info_t* mi, uint32_t index, const char* name,
     gtk_menu_item_set_label(GTK_MENU_ITEM(item->widget), label);
     g_free(label);
 
-    systray_set_tooltip(GTK_WIDGET(item->widget), tooltip);
+    if (tooltip)
+        systray_set_tooltip(GTK_WIDGET(item->widget), tooltip);
 
     switch(mi->type)
     {
@@ -285,8 +297,8 @@ void menu_info_item_update(menu_info_t* mi, uint32_t index, const char* name,
     if(mi->type == MENU_SINK && item == menu_info_item_get_by_name(mi, mi->default_name))
         ui_update_systray_icon(item);
 
-    if(notify && mis->settings.notify == NOTIFY_ALWAYS)
-        pulseaudio_update_volume_notification(item);
+    if(notify)
+        pulseaudio_process_update_volume_notification(item);
 }
 
 void menu_info_item_add(menu_info_t* mi, uint32_t index, const char* name,
@@ -389,7 +401,7 @@ GtkMenuShell* menu_info_item_context_menu(menu_info_item_t* mii)
         case MENU_SOURCE:
         {
             menu_type_t type = (mii->menu_info->type == MENU_SINK) ? MENU_INPUT : MENU_OUTPUT;
-            gchar* label = g_strdup_printf("move all %ss here",
+            gchar* label = g_strdup_printf("Move all %ss here",
                     menu_info_type_name(type));
             item = gtk_menu_item_new_with_label(label);
             g_free(label);
@@ -397,14 +409,14 @@ GtkMenuShell* menu_info_item_context_menu(menu_info_item_t* mii)
                     G_CALLBACK(menu_info_item_move_all_cb), mii);
             gtk_menu_shell_append(menu, item);
 
-            item = gtk_menu_item_new_with_label("rename");
+            item = gtk_menu_item_new_with_label("Rename");
             g_signal_connect(item, "button-press-event",
                     G_CALLBACK(menu_info_item_rename_cb), mii);
             gtk_menu_shell_append(menu, item);
             break;
         }
         case MENU_MODULE:
-            item = gtk_menu_item_new_with_label("unload");
+            item = gtk_menu_item_new_with_label("Unload");
             g_signal_connect(item, "button-press-event",
                     G_CALLBACK(menu_info_module_unload_cb), mii);
             gtk_menu_shell_append(menu, item);
