@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -118,13 +118,17 @@ void pulseaudio_move_all(menu_info_item_t* mii)
 
 void pulseaudio_move_success_cb(pa_context *c, int success, void *userdata)
 {
-    menu_info_item_t* to = userdata;
-    menu_info_item_t* from = to->menu_info->parent;
+    menu_info_item_t* mii = userdata;
 
     if(!success)
-        g_warning("failed to move %s '%s' to %s '%s'!\n",
-                menu_info_type_name(from->menu_info->type), from->name,
-                menu_info_type_name(to->menu_info->type), to->name);
+    {
+        g_warning("failed to move %s '%s'!\n",
+                menu_info_type_name(mii->menu_info->type), mii->desc);
+
+        menu_info_t* mi = mii->menu_info;
+        menu_info_item_update(mi, mii->index, mii->name, mii->desc, mii->volume,
+                mii->mute, NULL, mii->icon, mii->address, mii->target);
+    }
 }
 
 void pulseaudio_rename(menu_info_item_t* mii, const char* name)
@@ -217,12 +221,54 @@ void pulseaudio_set_volume_success_cb(pa_context *c, int success, void *userdata
     if(mii->menu_info->type == MENU_SINK || mii->menu_info->type == MENU_SOURCE)
         ui_set_volume_icon(mii);
 
-    if(mis->settings.notify != NOTIFY_NEVER)
+    if(mis->settings.n_systray_action)
     {
         pulseaudio_update_volume_notification(mii);
     }
 }
 
+void pulseaudio_process_update_volume_notification(menu_info_item_t* mii)
+{
+    menu_infos_t* mis = mii->menu_info->menu_infos;
+    menu_info_t* mi = mii->menu_info;
+
+    switch(mi->type)
+    {
+        case MENU_SERVER:
+        case MENU_MODULE:
+            return;
+
+        case MENU_INPUT:
+            if(mis->settings.n_stream_input)
+                break;
+            return;
+
+        case MENU_OUTPUT:
+            if(mis->settings.n_stream_output)
+                break;
+            return;
+
+        case MENU_SINK:
+            if(mis->settings.n_sink)
+                break;
+            if(mis->settings.n_sink_default && g_str_equal(mii->name, mi->default_name))
+                break;
+            return;
+
+        case MENU_SOURCE:
+            if(mis->settings.n_source)
+                break;
+            if(mis->settings.n_source_default && g_str_equal(mii->name, mi->default_name))
+                break;
+            return;
+
+        default:
+          return;
+    }
+
+    pulseaudio_update_volume_notification(mii);
+}
+
 void pulseaudio_update_volume_notification(menu_info_item_t* mii)
 {
     gchar* label = menu_info_item_label(mii);
@@ -312,3 +358,8 @@ void pulseaudio_module_unload_success_cb(pa_context *c, int success, void *userd
     if(!success)
         g_warning("failed to unload module %s!\n", mii->name);
 }
+
+void pulseaudio_terminate(void)
+{
+    pa_operation_unref(pa_context_exit_daemon(context, NULL, NULL));
+}
