@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -38,6 +38,7 @@ void pulseaudio_rename_success_cb(pa_context *c, int success, void *userdata);
 
 void pulseaudio_volume(menu_info_item_t* mii, int inc);
 void pulseaudio_set_volume_success_cb(pa_context *c, int success, void *userdata);
+void pulseaudio_process_update_volume_notification(menu_info_item_t* mii);
 void pulseaudio_update_volume_notification(menu_info_item_t* mii);
 
 void pulseaudio_toggle_mute(menu_info_item_t* mii);
@@ -49,4 +50,6 @@ void pulseaudio_module_load_success_cb(pa_context *c, uint32_t idx, void *userda
 void pulseaudio_module_unload(menu_info_item_t* mii);
 void pulseaudio_module_unload_success_cb(pa_context *c, int success, void *userdata);
 
+void pulseaudio_terminate(void);
+
 #endif /* PASYSTRAY_PULSEAUDIO_ACTION_H */
