@@ -1,7 +1,7 @@
 /***
   This file is part of PaSystray
 
-  Copyright (C) 2011-2015  Christoph Gysin
+  Copyright (C) 2011-2016  Christoph Gysin
 
   PaSystray is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -64,6 +64,13 @@ void systray_menu_create(menu_infos_t* mis)
     */
 
     systray_menu_add_separator(mis->menu);
+
+    GtkMenuShell* submenu = GTK_MENU_SHELL(gtk_menu_new());
+    GtkWidget* item = systray_add_item(mis->menu, "More...", NULL, NULL);
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), GTK_WIDGET(submenu));
+    systray_menu_add_action(submenu, "Terminate server", "process-stop",
+        G_CALLBACK(pulseaudio_terminate));
+
     systray_menu_add_action(mis->menu, "About", "help-about", G_CALLBACK(systray_about_dialog));
     systray_menu_add_action(mis->menu, "Quit", "application-exit", G_CALLBACK(quit));
 }
@@ -137,8 +144,10 @@ void systray_remove_placeholder(menu_info_t* mi)
     if(g_hash_table_size(mi->items) == 0)
     {
         GList* children = gtk_container_get_children(GTK_CONTAINER(mi->menu));
-        if(children)
+        if(children) {
             gtk_container_remove(GTK_CONTAINER(mi->menu), GTK_WIDGET(children->data));
+            g_list_free(children);
+        }
     }
 }
 
@@ -185,10 +194,12 @@ void systray_remove_radio_item(menu_info_t* mi, GtkWidget* item)
 
     /* update group */
     GList* children = gtk_container_get_children(GTK_CONTAINER(mi->menu));
-    if(children)
+    if(children) {
         mi->group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(children->data));
-    else
+        g_list_free(children);
+    } else {
         mi->group = NULL;
+    }
 }
 
 GtkWidget* systray_add_item(GtkMenuShell* menu, const char* desc, const char* tooltip, const char* icon)
